@@ -373,8 +373,8 @@ class Runner(ReprMixin):
 
         return klass, config_dict
 
-    def update(self, d: dict=None, section_path_str: str=None, **kwargs):
-        new_config = self._config.update(d, section_path_str, **kwargs)
+    def update(self, d: dict=None, section_path_str: str=None, pyfileconf_persist: bool = True, **kwargs):
+        new_config = self._config.update(d, section_path_str, pyfileconf_persist=pyfileconf_persist, **kwargs)
 
         if section_path_str in self._loaded_objects:
             apply_config(self._loaded_objects[section_path_str], new_config)
