@@ -297,40 +297,37 @@ class TestPipelineManagerRunIter(PipelineManagerTestBase):
         pipeline_manager.load()
         pipeline_manager.create('example_class_with_update.stuff.data')
         pipeline_manager.create('example_class_with_update.stuff2.data')
-        self.append_to_a_function_config('a = s.test_pipeline_manager.example_class_with_update.stuff.data\n')
-        self.append_to_a_function_config('b = s.test_pipeline_manager.example_class_with_update.stuff2.data')
+        self.append_to_a_function_config('a = s.test_pipeline_manager.example_class_with_update.stuff.data.a\n')
+        self.append_to_a_function_config('b = s.test_pipeline_manager.example_class_with_update.stuff2.data.a')
         pipeline_manager.reload()
+        pipeline_manager.run('stuff.a_function')  # run to set attribute dependencies. counts as one change
         sel = Selector()
         expect_results = [
             (
+                # two changes
                 (cd_d1_1, cd_d2_1),
-                (
-                    sel.test_pipeline_manager.example_class_with_update.stuff.data,
-                    sel.test_pipeline_manager.example_class_with_update.stuff2.data)
+                (2, 15)
             ),
             (
+                # one change
                 (cd_d1_1, cd_d2_2),
-                (
-                    sel.test_pipeline_manager.example_class_with_update.stuff.data,
-                    sel.test_pipeline_manager.example_class_with_update.stuff2.data)
+                (2, 30)
             ),
             (
+                # two changes
                 (cd_d1_2, cd_d2_1),
-                (
-                    sel.test_pipeline_manager.example_class_with_update.stuff.data,
-                    sel.test_pipeline_manager.example_class_with_update.stuff2.data)
+                (10, 15)
             ),
             (
+                # one change
                 (cd_d1_2, cd_d2_2),
-                (
-                    sel.test_pipeline_manager.example_class_with_update.stuff.data,
-                    sel.test_pipeline_manager.example_class_with_update.stuff2.data)
-            ),
+                (10, 30),
+            )
         ]
         iv = sel.test_pipeline_manager.stuff.a_function
         result = pipeline_manager.run_product(iv, config_dicts)
-        # 6 config resets, 6 config updates, corresponding to when config changes
-        assert ExampleClassWithCustomUpdate.num_updates == 12
+        # 7 changes, 14 operations in all: 7 config resets, 7 config updates, corresponding to when config changes
+        assert ExampleClassWithCustomUpdate.num_updates == 14
         assert result == expect_results
         for res, expect_res in zip(pipeline_manager.run_product_gen(iv, config_dicts), expect_results):
             assert res == expect_res
